@@ -124,7 +124,7 @@ class DropConstraintOp(MigrateOperation):
 
         :param constraint_name: name of the constraint.
         :param table_name: table name.
-        :param ``type_``: optional, required on MySQL.  can be
+        :param type_: optional, required on MySQL.  can be
          'foreignkey', 'primary', 'unique', or 'check'.
         :param schema: Optional schema name to operate within.  To control
          quoting of the schema outside of the default behavior, use
@@ -1345,9 +1345,9 @@ class AlterColumnOp(AlterTableOp):
         and  :class:`~sqlalchemy.types.Enum` may also
         add or drop constraints which accompany those
         types on backends that don't support them natively.
-        The ``existing_server_default`` argument is
-        used in this case as well to remove a previous
-        constraint.
+        The ``existing_type`` argument is
+        used in this case to identify and remove a previous
+        constraint that was bound to the type object.
 
         :param table_name: string name of the target table.
         :param column_name: string name of the target column,
@@ -1361,7 +1361,7 @@ class AlterColumnOp(AlterTableOp):
          Set to ``None`` to have the default removed.
         :param new_column_name: Optional; specify a string name here to
          indicate the new name within a column rename operation.
-        :param ``type_``: Optional; a :class:`~sqlalchemy.types.TypeEngine`
+        :param type_: Optional; a :class:`~sqlalchemy.types.TypeEngine`
          type object to specify a change to the column's type.
          For SQLAlchemy types that also indicate a constraint (i.e.
          :class:`~sqlalchemy.types.Boolean`, :class:`~sqlalchemy.types.Enum`),
@@ -1637,7 +1637,7 @@ class DropColumnOp(AlterTableOp):
         return operations.invoke(op)
 
     @classmethod
-    def batch_drop_column(cls, operations, column_name):
+    def batch_drop_column(cls, operations, column_name, **kw):
         """Issue a "drop column" instruction using the current
         batch migration context.
 
@@ -1648,7 +1648,7 @@ class DropColumnOp(AlterTableOp):
         """
         op = cls(
             operations.impl.table_name, column_name,
-            schema=operations.impl.schema)
+            schema=operations.impl.schema, **kw)
         return operations.invoke(op)
 
 
